Verifier

Struct Verifier 

pub struct Verifier<'a> { /* private fields */ }

Implementations

Source

impl<'a> Verifier<'a>

pub fn date( self, user_date: &mut String, date_type: DateType, ) -> Result<Output, VerifierError>

Checks if:

  • The inputted year is between 2022 to 2037.
  • The inputted month is between 01 to 12.
  • The inputted date is between 01 to 31.
  • The inputted date is empty.
  • Contains any extra spaces.
  • The date actually exists.
  • Removes any extra spaces and non-numeric characters.
  • Ensures proper char length for each part of the date.

Finally, tries to correct the date if it was not accepted by adding 0 if the beginning if the length is smaller than necessary or restores to the smallest or the largest date if date is beyond the accepted value.

pub fn amount(&self, user_amount: &mut String) -> Result<Output, VerifierError>

Checks if:

  • Amount is empty
  • Amount is zero or below
  • Amount text contains a calculation symbol
  • contains any extra spaces
  • removes any extra spaces and non-numeric characters

If the value is not float, tries to make it float ending with double zero

pub fn tx_method( &self, user_method: &mut String, ) -> Result<Output, VerifierError>

Checks if:

  • The Transaction method exists on the database.
  • The Transaction method is empty
  • contains any extra spaces

If the Transaction is not found, matches each character with the available Transaction Methods and corrects to the best matching one.

pub fn tx_type(&self, user_type: &mut String) -> Result<Output, VerifierError>

Checks if:

  • The transaction method starts with E, I, or T

Auto expands E to Expense, I to Income and T to transfer.

pub fn tags(&self, user_tag: &mut String)

Checks if:

  • All tags inserted is unique and is properly separated by commas
pub fn tags_forced( &self, user_tag: &mut String, ) -> Result<Output, VerifierError>

Checks if:

  • All tags inserted is unique and is properly separated by commas
  • There is no non-existing tags